0.3.0 (2016-04-03)
------------------

* It is now possible to stream data to an Excel document without providing
  a template. In this case all cells are formatted as text (no date or number
  formatting). If there is an error with the template provided by the user,
  fall back to this behaviour.
* Improve error handling (try to recover and log instead of raise)
* Change license

0.2.0 (2015-12-16)
------------------

* Add python 2.6 compatibility

0.1.0 (2015-12-16)
------------------

* First public version.
